@@ -1,7 +1,7 @@
 from app import Application
 from response import *
 from request import Request
-from request_handler import RequestHandler
+from request_handler import *
 from template import Template
 
-__version__ = '0.1.4'
+__version__ = '0.1.6'
