@@ -6,14 +6,12 @@ import mimetypes
 
 class RequestHandler(object):
     supported_methods = ('GET', 'PUT', 'POST', 'DELETE', 'OPTIONS', 'HEAD')
-    def __handle(self, method):
-        return Response('')
 
 
 class StaticFileHandler(RequestHandler):
     def get(self, request, path, static_path):
         loc = os.path.join(static_path, path)
-        if not loc.startswith(static_path) or not os.path.exists(loc):
+        if not loc.startswith(static_path) or not os.path.isfile(loc):
             return NotFoundResponse()
         r = Response(open(loc).read())
         mime = mimetypes.guess_type(loc)
